@@ -341,7 +341,7 @@ class Widget(view.Renderable):
     @only_if_initialized
     def _as_repeated(self, *args, **kw):
         cls = self.__class__
-        new_name = 'Repeated'+cls.__name__
+        new_name = 'Repeated' + cls.__name__
         new_class = type(new_name, (RepeatedWidget, cls), {})
         #log.debug("Generating %r for repeating %r", new_class, self)
         return Child(
@@ -995,7 +995,11 @@ class RepeatingWidgetBunch(WidgetBunch):
 
 
 class WidgetRepeater(Widget):
-    params = ["repetitions", "extra"]
+
+    params = {
+        'repetitions': 'Minimum number of repetitions',
+        'extra': 'Number of extra repetitions'
+    }
     widget = None
     repetitions = 3
     max_repetitions = None
@@ -1008,7 +1012,6 @@ class WidgetRepeater(Widget):
     def key(self):
         raise AttributeError("A WidgetRepeater has no meaningful key")
 
-
     def __new__(cls, id=None, parent=None, children=[], **kw):
         widget = kw.get('widget', getattr(cls, 'widget', None))
         if widget is None:
@@ -1023,23 +1026,24 @@ class WidgetRepeater(Widget):
         obj.c._widget = widget._as_repeated(obj, id=obj._id)
         return obj
 
-
     def update_params(self, d):
         super(WidgetRepeater,self).update_params(d)
         if d.get('max_repetitions', self.max_repetitions) is not None:
-            warn("max_repetitions is deperecated and no longer has any effect",
-                 DeprecationWarning, 3)
-        v_f = d['value_for']
-        a_f = d['args_for']
-        outputs = [
-            w.render(v_f(w), isextra=(w.repetition >= len(d['value'])), **a_f(w)) for w in d['children'].__iter__(
-                max(d['repetitions'], len(d['value']) + d.extra))
-            ]
-        d["output"] = '\n'.join(o for o in outputs if o)
+            warn("max_repetitions is deprecated and no longer has any effect",
+                DeprecationWarning, 3)
+        v_f, a_f = d['value_for'], d['args_for']
+        num = len(d['value'] or [])
+        outputs = [w.render(v_f(w), isextra=w.repetition >= num, **a_f(w))
+            for w in d['children'].__iter__(
+                max(d['repetitions'], num + d.extra))]
+        d['output'] = '\n'.join(output for output in outputs if output)
 
 
 class RepeatedWidget(Widget):
-    params = ["repetition"]
+
+    params = {
+        'repetition': 'The repetition number of the widget'
+    }
     repetition = 0
 
     @property
