@@ -6,7 +6,10 @@ import sys
 import os
 import tempfile
 import subprocess
-import md5
+try:
+        from hashlib import md5 as hash_constructor
+except ImportError:
+        from md5 import new as hash_constructor
 import mimetypes
 
 try:
@@ -67,13 +70,13 @@ class archive_tw_resources(Command):
         ("output=", "o",
          "Output directory. If it doesn't exist it will be created."),
         ("force", "f", "If output dir exists, it will be ovewritten"),
-        ("onepass", None, "If given, yuicompressor will only be called once "\
-                          "for each kind of file with a all files "\
-                          "together and then separated back into smaller "\
+        ("onepass", None, "If given, yuicompressor will only be called once "
+                          "for each kind of file with a all files "
+                          "together and then separated back into smaller "
                           "files"),
         ("compresslevel=", "c",
-         "Compression level: 0) for no compression (default). "\
-                            "1) for js-minification. "\
+         "Compression level: 0) for no compression (default). "
+                            "1) for js-minification. "
                             "2) for js & css compression"),
         ("yuicompressor=", None, "Name of the yuicompressor jar."),
         ("distributions=", "d",
@@ -105,7 +108,6 @@ class archive_tw_resources(Command):
         self.yuicompressor = 'yuicompressor.jar'
         self.requireonce = False
 
-
     def finalize_options(self):
         self.ensure_string("output")
         self.ensure_string("yuicompressor")
@@ -547,7 +549,7 @@ class aggregate_tw_resources(Command):
             # this must result in an existing variant_filename
             resource_aggregator.flush()
             inf = open(variant_filename)
-            hash = md5.new()
+            hash = hash_constructor()
             while True:
                 block = inf.read(4096)
                 if not block:
