@@ -23,7 +23,7 @@ finished) where they can be rendered and injected in the resulting html.
 
 ToscaWidgets' middleware can take care of injecting them automatically (default)
 but they can also be injected explicitly, example::
-    
+
 
    >>> from tw.api import JSLink, inject_resources
    >>> JSLink(link="http://example.com").inject()
@@ -45,7 +45,8 @@ import logging
 
 from webob import Request
 
-from tw import framework
+import tw
+
 from tw.core.util import MultipleReplacer
 
 log = logging.getLogger(__name__)
@@ -53,7 +54,7 @@ log = logging.getLogger(__name__)
 
 __all__ = ["inject_resources", "injector_middleware"]
 
-def injector_middleware(app):
+def injector_middleware(app, render_filter=None):
     """
     Middleware that injects resources (if any) into the page whenever the
     output is html (peeks into Content-Type header).
@@ -67,9 +68,14 @@ def injector_middleware(app):
         resp = req.get_response(app)
         content_type = resp.headers.get('Content-Type','text/plain').lower()
         if 'html' in content_type:
-            resources = framework.pop_resources()
+            # it crucial to us tw.framework here, and
+            # not import framework from tw, as it used
+            # to be, because otherwise we end up fetching
+            # the wrong framework - always the default (which
+            # defies the use of the StackedObjectProxy)
+            resources = tw.framework.pop_resources()
             if resources:
-                resp.body = inject_resources(resp.body, resources, resp.charset)
+                resp.body = inject_resources(resp.body, resources, resp.charset, render_filter=render_filter)
         return resp(environ, start_response)
     return _injector
 
@@ -84,15 +90,18 @@ class _ResourceInjector(MultipleReplacer):
             }, re.I|re.M)
 
     def _injector_for_location(self, key, after=True):
-        def inject(group, resources, encoding):
-            inj = u'\n'.join(r.render() for r in resources.get(key, []))
+        def inject(group, resources, encoding, render_filter, environ):
+            if render_filter is None:
+                def render_filter(_environ, resource):
+                    return resource.render()
+            inj = u'\n'.join([render_filter(environ, r) for r in resources.get(key, [])])
             inj = inj.encode(encoding)
             if after:
                 return group + inj
             return  inj + group
         return inject
 
-    def __call__(self, html, resources=None, encoding=None):
+    def __call__(self, html, resources=None, encoding=None, render_filter=None, environ=None):
         """Injects resources, if any, into html string when called.
 
         .. note::
@@ -102,18 +111,23 @@ class _ResourceInjector(MultipleReplacer):
 
         ``html`` must be a ``encoding`` encoded string. If ``encoding`` is not
         given it will be tried to be derived from a <meta>.
-        
+
         Resources for current request can be obtained by calling
         ``tw.framework.pop_resources()``. This will remove resources
         from request and a further call to ``pop_resources()`` will return an
         empty dict.
         """
         if resources is None:
-            resources = framework.pop_resources()
+            # it crucial to us tw.framework here, and
+            # not import framework from tw, as it used
+            # to be, because otherwise we end up fetching
+            # the wrong framework - always the default (which
+            # defies the use of the StackedObjectProxy)
+            resources = tw.framework.pop_resources()
         if resources:
             # Only inject if there are resources registered for injection
             encoding = encoding or find_charset(html) or 'ascii'
-            html = MultipleReplacer.__call__(self, html, resources, encoding)
+            html = MultipleReplacer.__call__(self, html, resources, encoding, render_filter=render_filter, environ=None)
         return html
 
 
