@@ -23,9 +23,9 @@ def _extract_config():
 
 class TWInitFilter(BaseFilter):
     """Sort-of-emulates TWWidgetsMiddleware + Paste's RegistryManager.
-    
+
     Takes care of preparing the hostframework for a request.
-    
+
     """
 
     def __init__(self, host_framework, prefix='/toscawidgets',
@@ -47,11 +47,11 @@ class TWInitFilter(BaseFilter):
         """Intercepts requests for static files and serves them."""
         if not self.serve_files:
             return
-            
+
         req, resp = cherrypy.request, cherrypy.response
         path = req.path
         if path.startswith(self.host_framework.webpath):
-            path = path[len(self.host_framework.webpath):]        
+            path = path[len(self.host_framework.webpath):]
         if path.startswith(self.prefix):
             reg = resources.registry
             path = path[len(self.prefix)+len(reg.prefix):]
@@ -59,8 +59,7 @@ class TWInitFilter(BaseFilter):
                 path_info = path
                 params = req.params
                 environ = {}
-            stream, ct, enc = reg.get_stream_type_encoding(
-                FakeRequest())
+            stream, ct, enc = reg.get_stream_type_encoding(FakeRequest)
             if stream:
                 resp.body = stream
                 if ct:
@@ -88,7 +87,7 @@ class TWInitFilter(BaseFilter):
             response.body = [html]
             # Delete Content-Length header so finalize() recalcs it.
             response.headers.pop("Content-Length", None)
-        
+
     def on_end_resource(self):
         log.debug("TWFilter: on_end_resource")
         try:
@@ -100,6 +99,6 @@ class TWInitFilter(BaseFilter):
 
 
 def start_extension(host_framework, **filter_args):
-    cherrypy.root._cp_filters.append(TWInitFilter(host_framework, 
+    cherrypy.root._cp_filters.append(TWInitFilter(host_framework,
                                      **filter_args))
     log.info("Added TWInitFilter")
