@@ -12,15 +12,17 @@ from tw.core.registry import Registry
 
 log = logging.getLogger(__name__)
 
+
 def _extract_config():
     c = cherrypy.config.copy()
     return c
 
+
 class TWTool(cherrypy.Tool):
     """Sort-of-emulates TWWidgetsMiddleware + Paste's RegistryManager.
-    
+
     Takes care of preparing the hostframework for a request.
-    
+
     """
 
     def __init__(self, host_framework, prefix='/toscawidgets',
@@ -28,13 +30,13 @@ class TWTool(cherrypy.Tool):
         self.serve_files = serve_files
         self.prefix = prefix
         self.host_framework = host_framework
-        
+
         return super(TWTool, self).__init__("on_start_resource", self.on_start_resource)
 
     def on_start_resource(self):
         log.debug("TWTool: on_start_resource")
 
-        environ = cherrypy.request.wsgi_environ         
+        environ = cherrypy.request.wsgi_environ
         registry = environ.setdefault('paste.registry', Registry())
         environ['toscawidgets.prefix'] = self.prefix
         registry.prepare()
@@ -45,16 +47,19 @@ class TWTool(cherrypy.Tool):
         """Intercepts requests for static files and serves them."""
         if not self.serve_files:
             return
-        
+
         req, resp = cherrypy.request, cherrypy.response
         path = req.path_info
         if path.startswith(self.host_framework.webpath):
             path = path[len(self.host_framework.webpath):]
-        
         if path.startswith(self.prefix):
             reg = resources.registry
             path = path[len(self.prefix)+len(reg.prefix):]
-            stream, ct, enc = reg.get_stream_type_encoding(path)
+            class FakeRequest(object):
+                path_info = path
+                params = req.params
+                environ = {}
+            stream, ct, enc = reg.get_stream_type_encoding(FakeRequest)
             if stream:
                 resp.body = stream
                 if ct:
@@ -93,7 +98,7 @@ class TWTool(cherrypy.Tool):
             registry = environ.get('paste.registry', None)
             if registry:
                 registry.cleanup()
-    
+
     def _setup(self):
         conf = self._merged_args()
         p = conf.pop("priority", None)
